@@ -4,26 +4,49 @@ from copick import __version__ as version
 from copick.cli.add import add
 from copick.cli.browse import browse
 from copick.cli.config import config
+from copick.cli.cp import cp
+from copick.cli.deposit import deposit
 from copick.cli.ext import load_plugin_commands
-from copick.cli.info import info
+from copick.cli.grouped_cli import GroupedCommandGroup
+from copick.cli.info import get_installed_plugin_packages, info
+from copick.cli.mv import mv
 from copick.cli.new import new
+from copick.cli.rm import rm
 from copick.cli.stats import stats
 from copick.cli.sync import sync
 from copick.util.log import get_logger
 
 logger = get_logger(__name__)
 
+# Define command categories for organized help output
+COMMAND_CATEGORIES = {
+    "Data Management": ["add", "cp", "mv", "new", "rm", "sync"],
+    "Data Processing": ["convert", "inference", "logical", "process", "training", "evaluation"],
+    "Utilities": ["browse", "config", "deposit", "info", "setup", "stats"],
+}
 
-@click.group()
+
+@click.group(cls=GroupedCommandGroup, command_categories=COMMAND_CATEGORIES)
 @click.version_option(version=version, message="copick %(version)s")
 @click.pass_context
 def _cli(ctx):
-    text = f"copick {version}"
+    plugin_packages = get_installed_plugin_packages()
+    plugins = ""
+    if plugin_packages:
+        for package in sorted(plugin_packages):
+            plugins += f" {package} |"
+        plugins = plugins[:-2]
+        plugins = f"{plugins}"
+
+    text = f"copick {version} |{plugins}" if plugins else f"copick {version}"
     logger.info(text)
     logger.info(f"{'-'*len(text)}")
 
 
-@click.group(short_help="Run inference on copick tomograms.")
+@click.group(
+    short_help="Run inference on copick tomograms.",
+    no_args_is_help=True,
+)
 @click.pass_context
 def inference(ctx):
     """
@@ -34,7 +57,10 @@ def inference(ctx):
     pass
 
 
-@click.group(short_help="Train a model with copick data.")
+@click.group(
+    short_help="Train a model with copick data.",
+    no_args_is_help=True,
+)
 @click.pass_context
 def training(ctx):
     """
@@ -45,7 +71,10 @@ def training(ctx):
     pass
 
 
-@click.group(short_help="Evaluate model performance.")
+@click.group(
+    short_help="Evaluate model performance.",
+    no_args_is_help=True,
+)
 @click.pass_context
 def evaluation(ctx):
     """
@@ -56,7 +85,10 @@ def evaluation(ctx):
     pass
 
 
-@click.group(short_help="Apply processing method to copick entity.")
+@click.group(
+    short_help="Apply processing method to copick entity.",
+    no_args_is_help=True,
+)
 @click.pass_context
 def process(ctx):
     """
@@ -67,7 +99,10 @@ def process(ctx):
     pass
 
 
-@click.group(short_help="Convert one copick type to another.")
+@click.group(
+    short_help="Convert one copick type to another.",
+    no_args_is_help=True,
+)
 @click.pass_context
 def convert(ctx):
     """
@@ -78,6 +113,36 @@ def convert(ctx):
     pass
 
 
+@click.group(
+    short_help="Perform logical operations on copick objects.",
+    no_args_is_help=True,
+)
+@click.pass_context
+def logical(ctx):
+    """
+    Logical operation commands for Copick.
+
+    This group contains commands for boolean operations, distance-based filtering,
+    and point inclusion/exclusion operations on meshes, segmentations, and picks.
+    """
+    pass
+
+
+@click.group(
+    short_help="Setup and manage external integrations.",
+    no_args_is_help=True,
+)
+@click.pass_context
+def setup(ctx):
+    """
+    Setup commands for Copick.
+
+    This group contains commands for setting up and managing external integrations
+    like MCP servers, database connections, and other third-party tools.
+    """
+    pass
+
+
 def add_core_commands(cmd: click.group) -> click.group:
     """
     Add core commands to the CLI.
@@ -92,8 +157,12 @@ def add_core_commands(cmd: click.group) -> click.group:
     cmd.add_command(add)
     cmd.add_command(browse)
     cmd.add_command(config)
+    cmd.add_command(cp)
+    cmd.add_command(deposit)
     cmd.add_command(info)
+    cmd.add_command(mv)
     cmd.add_command(new)
+    cmd.add_command(rm)
     cmd.add_command(stats)
     cmd.add_command(sync)
 
@@ -139,6 +208,16 @@ def add_plugin_commands(cmd: click.group) -> click.group:
         for command in convert_commands:
             convert.add_command(command[0])
 
+    if logical_commands := load_plugin_commands("logical"):
+        cmd.add_command(logical)
+        for command in logical_commands:
+            logical.add_command(command[0])
+
+    if setup_commands := load_plugin_commands("setup"):
+        cmd.add_command(setup)
+        for command in setup_commands:
+            setup.add_command(command[0])
+
     return cmd
 
 
